import os
import unittest


from bold_retriever import bold_retriever as br


class TestGenerateContent(unittest.TestCase):

    def setUp(self):
        self.db = "COX1"

        this_path = os.path.abspath(os.path.dirname(__file__))
        self.filename = os.path.join(this_path, "otu_50.fas")
        self.output_filename = self.filename + "_output.csv"

    def test_generate_content(self):
        results = br.generate_output_content_for_file(self.output_filename,
                                                      self.filename,
                                                      self.db)
        expected = 'Processed all sequences.'
        self.assertEqual(expected, results)

        lines = open(self.output_filename, "r").readlines()[0]
        expected = 'nohit,OTU_50'
        self.assertTrue(lines.startswith(expected))


if __name__ == "__main__":
    runner = unittest.TextTestRunner(verbosity=2)
    unittest.main(testRunner=runner)



import os
import subprocess
import unittest

from bold_retriever import bold_retriever as br


class CmdlineTest(unittest.TestCase):

    def setUp(self):
        self.parser = br.create_parser()

    # User does not enter any argument
    def test_cmdline_emtpy_args(self):
        with self.assertRaises(SystemExit):
            self.parser.parse_args([])

    # User enters only one argument
    def test_cmdline_file(self):
        with self.assertRaises(SystemExit):
            self.parser.parse_args(['-f', 'ionx23b.fas'])

    # User enters both arguments
    def test_cmdline(self):
        args = self.parser.parse_args(['-f', 'ionx23b.fas', '-db', 'COX1'])
        expected = 'COX1'
        self.assertEqual(expected, args.db)

    def test_cmdline_main(self):
        cwd = os.path.abspath(os.path.dirname(__file__))
        bold_retriever = os.path.join(cwd, '..', 'bold_retriever',
                                      'bold_retriever.py')
        print(bold_retriever)
        cmd = "python " + bold_retriever + " -f " + os.path.join(cwd,
                                                                 'otu99.fas')
        cmd += " -db COX1_SPECIES"
        p = subprocess.check_call(cmd, shell=True)
        self.assertEqual(0, p)

    def test_get_args(self):
        args = self.parser.parse_args(['-f', 'ionx13.fas', '-db', 'COX1'])
        f, db = br.get_args(args)
        self.assertEqual(f, 'ionx13.fas')
        self.assertEqual(db, 'COX1')

    def test_get_started(self):
        test_folder = os.path.abspath(os.path.dirname(__file__))
        input_file = os.path.join(test_folder, 'ionx13.fas')
        result_file = os.path.join(test_folder, 'ionx13.fas_output.csv')

        args = self.parser.parse_args(['-f', input_file, '-db', 'COX1'])
        br.get_started(args)

        self.assertTrue(os.path.isfile(result_file))

    def test_otu99(self):
        """It should pass despite returning empty list for classification."""
        test_folder = os.path.abspath(os.path.dirname(__file__))
        input_file = os.path.join(test_folder, 'otu99.fas')
        args = self.parser.parse_args(['-f', input_file, '-db',
                                       'COX1_SPECIES'])
        br.get_started(args)
        result_file = os.path.join(test_folder, 'otu99.fas_output.csv')
        self.assertTrue(os.path.isfile(result_file))
